import { EditorState, Transaction } from "../../state/src";
import { BehaviorStore, Slot } from "../../extension/src/extension";
import { DocView } from "./docview";
import { InputState, MouseSelectionUpdate } from "./input";
import { Rect } from "./dom";
import { BlockInfo } from "./heightmap";
import { Viewport } from "./viewport";
import { ViewExtension, ViewField, ViewUpdate, Effect } from "./extension";
export interface EditorConfig {
    state: EditorState;
    extensions?: ViewExtension[];
    root?: Document | ShadowRoot;
    dispatch?: (tr: Transaction) => void;
}
export declare class EditorView {
    state: EditorState;
    viewport: Viewport;
    dispatch: (tr: Transaction) => void;
    root: DocumentOrShadowRoot;
    readonly dom: HTMLElement;
    readonly contentDOM: HTMLElement;
    inputState: InputState;
    readonly docView: DocView;
    readonly behavior: BehaviorStore;
    fields: ReadonlyArray<ViewField<any>>;
    fieldValues: any[];
    private plugins;
    private editorAttrs;
    private contentAttrs;
    updating: boolean;
    constructor(config: EditorConfig);
    setState(state: EditorState, extensions?: ViewExtension[]): void;
    update(transactions?: Transaction[], metadata?: Slot[]): void;
    updatePlugins(update: ViewUpdate): void;
    initInner(state: EditorState, viewport: Viewport): void;
    updateInner(update: ViewUpdate, viewport: Viewport): void;
    withUpdating(f: () => void): void;
    getField<T>(field: ViewField<T>): T;
    getEffect<V>(type: Effect<V>): ReadonlyArray<V>;
    domAtPos(pos: number): {
        node: Node;
        offset: number;
    };
    blockAtHeight(height: number, editorTop?: number): BlockInfo;
    lineAtHeight(height: number, editorTop?: number): BlockInfo;
    lineAt(pos: number, editorTop?: number): BlockInfo;
    viewportLines(f: (height: BlockInfo) => void, editorTop?: number): void;
    readonly contentHeight: number;
    movePos(start: number, direction: "forward" | "backward" | "left" | "right", granularity?: "character" | "word" | "line" | "lineboundary", action?: "move" | "extend"): number;
    posAtCoords(coords: {
        x: number;
        y: number;
    }): number;
    coordsAtPos(pos: number): Rect | null;
    readonly defaultCharacterWidth: number;
    readonly defaultLineHeight: number;
    startMouseSelection(event: MouseEvent, update: MouseSelectionUpdate): void;
    hasFocus(): boolean;
    focus(): void;
    destroy(): void;
}
