import { EditorState, Transaction, ChangeSet } from "../../state/src";
import { StyleModule } from "style-mod";
import { Viewport } from "./viewport";
import { DecorationSet, Decoration } from "./decoration";
import { Extension, Slot, SlotType } from "../../extension/src/extension";
import { EditorView } from "./editorview";
import { Attrs } from "./attributes";
export declare type Effect<T> = SlotType<(field: any) => T>;
export declare class ViewField<V> {
    readonly create: (view: EditorView) => V;
    readonly update: (value: V, update: ViewUpdate) => V;
    readonly effects: Slot<(field: V) => any>[];
    constructor({ create, update, effects }: {
        create: (view: EditorView) => V;
        update: (value: V, update: ViewUpdate) => V;
        effects?: Slot<(field: V) => any>[];
    });
    readonly extension: Extension;
    static decorationEffect: SlotType<(field: any) => import("../../rangeset/src/rangeset").RangeSet<Decoration>>;
    static editorAttributeEffect: SlotType<(field: any) => Attrs>;
    static contentAttributeEffect: SlotType<(field: any) => Attrs>;
    static decorations({ create, update, map }: {
        create?: (view: EditorView) => DecorationSet;
        update: (deco: DecorationSet, update: ViewUpdate) => DecorationSet;
        map?: boolean;
    }): Extension;
    static editorAttributes: (value: Attrs | ((view: EditorView) => Attrs), update?: (value: Attrs, update: ViewUpdate) => Attrs) => Extension;
    static contentAttributes: (value: Attrs | ((view: EditorView) => Attrs), update?: (value: Attrs, update: ViewUpdate) => Attrs) => Extension;
}
export declare class ViewExtension extends Extension {
}
export declare const viewField: import("../../extension/src/extension").Behavior<ViewField<any>>;
export declare const handleDOMEvents: import("../../extension/src/extension").Behavior<{
    [key: string]: (view: EditorView, event: any) => boolean;
}>;
export declare const clickAddsSelectionRange: import("../../extension/src/extension").Behavior<(event: MouseEvent) => boolean>;
export declare const dragMovesSelection: import("../../extension/src/extension").Behavior<(event: MouseEvent) => boolean>;
export declare type ViewPlugin = {
    update?: (update: ViewUpdate) => void;
    destroy?: () => void;
};
export declare const viewPlugin: import("../../extension/src/extension").Behavior<(view: EditorView) => ViewPlugin>;
export declare const styleModule: import("../../extension/src/extension").Behavior<StyleModule<{}>>;
export declare const focusChange: SlotType<boolean>;
export declare class ViewUpdate {
    readonly view: EditorView;
    readonly transactions: ReadonlyArray<Transaction>;
    readonly metadata: ReadonlyArray<Slot>;
    readonly state: EditorState;
    readonly changes: ChangeSet;
    readonly prevState: EditorState;
    readonly prevFields: ReadonlyArray<ViewField<any>>;
    readonly prevFieldValues: ReadonlyArray<any>;
    readonly prevViewport: Viewport;
    constructor(view: EditorView, transactions?: ReadonlyArray<Transaction>, metadata?: ReadonlyArray<Slot>);
    readonly viewport: Viewport;
    prevField<T>(field: ViewField<T>): T;
    readonly viewportChanged: boolean;
    readonly docChanged: boolean;
    getMeta<T>(type: SlotType<T>): T | undefined;
}
export declare function getField<T, D = undefined>(field: ViewField<T>, fields: ReadonlyArray<ViewField<any>>, values: ReadonlyArray<any>, defaultValue?: D): T | D;
